@@ -20,7 +20,6 @@
 from rest_framework.views import APIView
 from rest_framework.response import Response
 from rest_framework import serializers
-from rest_framework.exceptions import ParseError
 
 from hyperkitty.models import Tag
 from hyperkitty.lib import get_store
@@ -40,6 +39,8 @@ class EmailSerializer(serializers.Serializer):
     subject = serializers.CharField()
     in_reply_to = serializers.CharField()
     date = serializers.DateTimeField()
+    likes = serializers.IntegerField()
+    dislikes = serializers.IntegerField()
 
 class EmailLinkSerializer(serializers.Serializer):
     list_name = serializers.EmailField()
@@ -83,7 +84,7 @@ class EmailResource(APIView):
 
     def get(self, request, mlist_fqdn, messageid):
         store = get_store(request)
-        email = store.get_message_by_id_from_list(mlist_fqdn, messageid)
+        email = store.get_message_by_hash_from_list(mlist_fqdn, messageid)
         if not email:
             return Response(status=404)
         else:
@@ -104,32 +105,6 @@ class ThreadResource(APIView):
             return Response(ThreadSerializer(thread).data)
 
 
-class SearchResource(APIView):
-    """ Resource used to search the archives using the REST API.
-    """
-
-    def get(self, request, mlist_fqdn, field, keyword):
-        fields = ['Subject', 'Content', 'SubjectContent', 'From']
-        if field not in fields:
-            raise ParseError(detail="Unknown field: " + field + ". Supported fields are " + ", ".join(fields))
-
-        store = get_store(request)
-        threads = None
-        if field == 'Subject':
-            threads = store.search_list_for_subject(mlist_fqdn, keyword)
-        elif field == 'Content':
-            threads = store.search_list_for_content(mlist_fqdn, keyword)
-        elif field == 'SubjectContent':
-            threads = store.search_list_for_content_subject(mlist_fqdn, keyword)
-        elif field == 'From':
-            threads = store.search_list_for_sender(mlist_fqdn, keyword)
-
-        if not threads:
-            return Response(status=404)
-        else:
-            return Response(EmailSerializer(threads, many=True).data)
-
-
 class TagResource(APIView):
     """
     Resource used to retrieve tags from the database using the REST API.
