@@ -75,37 +75,6 @@ function setup_vote(baseElem) {
 
 
 
-/*
- * New messages (or replies)
- */
-
-function setup_attachments(baseElem) {
-    if (!baseElem) {
-        baseElem = document;
-    }
-    function add_attach_form (e) {
-        e.preventDefault();
-        var form = $(this).parents("form").first();
-        form.find(".attach-files-template")
-            .clone().removeClass("attach-files-template")
-            .appendTo(form.find(".attach-files"));
-        form.find(".attach-files span a").click(function (e) {
-            e.preventDefault();
-            $(this).parent().remove();
-            if (form.find(".attach-files input").length === 0) {
-                form.find(".attach-files-add").hide();
-                form.find(".attach-files-first").show();
-            };
-        });
-        form.find(".attach-files-first").hide();
-        form.find(".attach-files-add").show();
-    }
-    $(baseElem).find(".attach-files-add").click(add_attach_form);
-    $(baseElem).find(".attach-files-first").click(add_attach_form);
-}
-
-
-
 /*
  * Recent activity bar chart
  */
@@ -296,5 +265,4 @@ $(document).ready(function() {
     setup_months_list();
     setup_disabled_tooltips();
     setup_flash_messages();
-    setup_attachments();
 });
