@@ -64,12 +64,13 @@ function setup_category() {
 
 function setup_tags() {
     function post_tags(e) {
+        var form = $(this);
         e.preventDefault();
         $.ajax({
             type: "POST",
             dataType: "json",
-            data : $(this).serialize(),
-            url: $(this).attr("action"),
+            data : form.serialize(),
+            url: form.attr("action"),
             success: function(data) {
                 $("#tags").html(data.html);
                 $("#tags form").submit(post_tags);
@@ -77,11 +78,13 @@ function setup_tags() {
                     e.preventDefault();
                     $(this).parents("form").first().submit();
                 });
-                $(this).find("#id_tag").value("");
             },
             error: function(jqXHR, textStatus, errorThrown) {
                 // authentication and invalid data
                 alert(jqXHR.responseText);
+            },
+            complete: function(jqXHR, textStatus) {
+                form.find("#id_tag").val("");
             }
         });
     }
@@ -320,7 +323,6 @@ function update_thread_replies(url) {
                 fold_quotes(newcontent);
                 setup_disabled_tooltips(newcontent);
                 setup_vote(newcontent);
-                setup_attachments(newcontent);
                 // load the rest if applicable
                 if (data.more_pending) {
                     load_more(url+"&offset="+data.next_offset);
