@@ -17,9 +17,5 @@
 # HyperKitty.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Author: Aamir Khan <syst3m.w0rm@gmail.com>
+# Author: Aurelien Bompard <abompard@fedoraproject.org>
 # 
-
-from hyperkitty.tests.test_views import *
-from hyperkitty.tests.test_models import *
-from hyperkitty.tests.test_templatetags import *
-from hyperkitty.tests.test_lib import *
